@@ -1,4 +1,4 @@
-/* Copyright 2011--2017 The Tor Project
+/* Copyright 2011--2018 The Tor Project
  * See LICENSE for licensing information */
 
 package org.torproject.onionoo.server;
@@ -113,8 +113,8 @@ public class ResponseBuilder {
   }
 
   public void buildResponse(PrintWriter pw) {
-    writeRelays(orderedRelays, pw);
-    writeBridges(orderedBridges, pw);
+    writeRelays(this.orderedRelays, pw);
+    writeBridges(this.orderedBridges, pw);
   }
 
   private int charsWritten = 0;
@@ -123,9 +123,9 @@ public class ResponseBuilder {
     return this.charsWritten;
   }
 
-  private static final String PROTOCOL_VERSION = "5.0";
+  private static final String PROTOCOL_VERSION = "5.1";
 
-  private static final String NEXT_MAJOR_VERSION_SCHEDULED = null;
+  private static final String NEXT_MAJOR_VERSION_SCHEDULED = "2018-04-14";
 
   private void writeRelays(List<SummaryDocument> relays, PrintWriter pw) {
     this.write(pw, "{\"version\":\"%s\",\n", PROTOCOL_VERSION);
@@ -210,8 +210,7 @@ public class ResponseBuilder {
   }
 
   private String writeRelaySummaryLine(SummaryDocument entry) {
-    String nickname = !entry.getNickname().equals("Unnamed")
-        ? entry.getNickname() : null;
+    String nickname = entry.getNickname();
     String fingerprint = entry.getFingerprint();
     String running = entry.isRunning() ? "true" : "false";
     List<String> addresses = entry.getAddresses();
@@ -221,19 +220,16 @@ public class ResponseBuilder {
       addressesBuilder.append((written++ > 0 ? "," : "") + "\""
           + address.toLowerCase() + "\"");
     }
-    return String.format("{%s\"f\":\"%s\",\"a\":[%s],\"r\":%s}",
-        (nickname == null ? "" : "\"n\":\"" + nickname + "\","),
-        fingerprint, addressesBuilder.toString(), running);
+    return String.format("{\"n\":\"%s\",\"f\":\"%s\",\"a\":[%s],\"r\":%s}",
+        nickname, fingerprint, addressesBuilder.toString(), running);
   }
 
   private String writeBridgeSummaryLine(SummaryDocument entry) {
-    String nickname = !entry.getNickname().equals("Unnamed")
-        ? entry.getNickname() : null;
+    String nickname = entry.getNickname();
     String hashedFingerprint = entry.getFingerprint();
     String running = entry.isRunning() ? "true" : "false";
-    return String.format("{%s\"h\":\"%s\",\"r\":%s}",
-         (nickname == null ? "" : "\"n\":\"" + nickname + "\","),
-         hashedFingerprint, running);
+    return String.format("{\"n\":\"%s\",\"h\":\"%s\",\"r\":%s}",
+        nickname, hashedFingerprint, running);
   }
 
   private String writeDetailsLines(SummaryDocument entry) {
